@@ -307,6 +307,15 @@ class TestS3Transfers(unittest.TestCase):
                                 Key=key)
         return True
 
+    def wait_until_object_exists(self, key_name, extra_params=None,
+                                 min_successes=3):
+        waiter = self.client.get_waiter('object_exists')
+        params = {'Bucket': self.bucket_name, 'Key': key_name}
+        if extra_params is not None:
+            params.update(extra_params)
+        for _ in range(min_successes):
+            waiter.wait(**params)
+
     def create_s3_transfer(self, config=None):
         return boto3.s3.transfer.S3Transfer(self.client,
                                             config=config)
@@ -367,6 +376,7 @@ class TestS3Transfers(unittest.TestCase):
             Bucket=self.bucket_name, Key='foo', Body=b'beach')
         self.addCleanup(self.delete_object, 'foo')
 
+        self.wait_until_object_exists('foo')
         self.client.download_fileobj(
             Bucket=self.bucket_name, Key='foo', Fileobj=fileobj)
 
@@ -516,6 +526,7 @@ class TestS3Transfers(unittest.TestCase):
         transfer = self.create_s3_transfer()
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
+        self.wait_until_object_exists('foo.txt', extra_params=extra_args)
         transfer.download_file(self.bucket_name, 'foo.txt',
                                download_path, extra_args=extra_args)
         with open(download_path, 'rb') as f:
@@ -555,6 +566,7 @@ class TestS3Transfers(unittest.TestCase):
             self.addCleanup(self.delete_object, 'foo.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
+        self.wait_until_object_exists('foo.txt')
         transfer.download_file(self.bucket_name, 'foo.txt',
                                download_path)
         assert_files_equal(filename, download_path)
@@ -571,6 +583,7 @@ class TestS3Transfers(unittest.TestCase):
             self.addCleanup(self.delete_object, 'foo.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
+        self.wait_until_object_exists('foo.txt')
         transfer.download_file(self.bucket_name, 'foo.txt',
                                download_path)
         assert_files_equal(filename, download_path)
@@ -583,6 +596,7 @@ class TestS3Transfers(unittest.TestCase):
         self.addCleanup(self.delete_object, 'foo.txt')
         download_path = os.path.join(self.files.rootdir, 'a', 'b', 'c',
                                      'downloaded.txt')
+        self.wait_until_object_exists('foo.txt')
         with self.assertRaises(IOError):
             transfer.download_file(self.bucket_name, 'foo.txt', download_path)
 
@@ -598,6 +612,7 @@ class TestS3Transfers(unittest.TestCase):
             self.addCleanup(self.delete_object, 'foo.txt')
         download_path = os.path.join(self.files.rootdir, 'a', 'b', 'c',
                                      'downloaded.txt')
+        self.wait_until_object_exists('foo.txt')
         with self.assertRaises(IOError):
             transfer.download_file(self.bucket_name, 'foo.txt', download_path)
 
@@ -613,11 +628,38 @@ class TestS3Transfers(unittest.TestCase):
         self.addCleanup(self.delete_object, 'foo.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
+        self.wait_until_object_exists('foo.txt')
         self.client.download_file(Bucket=self.bucket_name,
                                   Key='foo.txt',
                                   Filename=download_path)
         assert_files_equal(filename, download_path)
 
+    def test_transfer_methods_do_not_use_threads(self):
+        # This is just a smoke test to make sure that
+        # setting use_threads to False has no issues transferring files as
+        # the non-threaded implementation is ran under the same integration
+        # and functional tests in s3transfer as the normal threaded
+        # implementation
+        #
+        # The methods used are arbitrary other than one of the methods
+        # use ``boto3.s3.transfer.S3Transfer`` and the other should be
+        # using ``s3transfer.manager.TransferManager`` directly
+        content = b'my content'
+        filename = self.files.create_file('myfile', content.decode('utf-8'))
+        key = 'foo'
+        config = boto3.s3.transfer.TransferConfig(use_threads=False)
+
+        self.client.upload_file(
+            Bucket=self.bucket_name, Key=key, Filename=filename,
+            Config=config)
+        self.addCleanup(self.delete_object, key)
+        self.assertTrue(self.object_exists(key))
+
+        fileobj = six.BytesIO()
+        self.client.download_fileobj(
+            Bucket=self.bucket_name, Key='foo', Fileobj=fileobj, Config=config)
+        self.assertEqual(fileobj.getvalue(), content)
+
     def test_transfer_methods_through_bucket(self):
         # This is just a sanity check to ensure that the bucket interface work.
         key = 'bucket.txt'
